# {{classname}}

All URIs are relative to *https://demo.firefly-iii.org/api*

Method | HTTP request | Description
------------- | ------------- | -------------
[**DeleteAccount**](AccountsApi.md#DeleteAccount) | **Delete** /v1/accounts/{id} | Permanently delete account.
[**GetAccount**](AccountsApi.md#GetAccount) | **Get** /v1/accounts/{id} | Get single account.
[**ListAccount**](AccountsApi.md#ListAccount) | **Get** /v1/accounts | List all accounts.
[**ListAttachmentByAccount**](AccountsApi.md#ListAttachmentByAccount) | **Get** /v1/accounts/{id}/attachments | Lists all attachments.
[**ListPiggyBankByAccount**](AccountsApi.md#ListPiggyBankByAccount) | **Get** /v1/accounts/{id}/piggy-banks | List all piggy banks related to the account.
[**ListTransactionByAccount**](AccountsApi.md#ListTransactionByAccount) | **Get** /v1/accounts/{id}/transactions | List all transactions related to the account.
[**StoreAccount**](AccountsApi.md#StoreAccount) | **Post** /v1/accounts | Create new account.
[**UpdateAccount**](AccountsApi.md#UpdateAccount) | **Put** /v1/accounts/{id} | Update existing account.

# **DeleteAccount**
> DeleteAccount(ctx, id, optional)
Permanently delete account.

Will permanently delete an account. Any associated transactions and piggy banks are ALSO deleted. Cannot be recovered from. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
  **id** | **string**| The ID of the account. | 
 **optional** | ***AccountsApiDeleteAccountOpts** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a pointer to a AccountsApiDeleteAccountOpts struct
Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------

 **xTraceId** | [**optional.Interface of string**](.md)| Unique identifier associated with this request. | 

### Return type

 (empty response body)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth), [local_bearer_auth](../README.md#local_bearer_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **GetAccount**
> AccountSingle GetAccount(ctx, id, optional)
Get single account.

Returns a single account by its ID. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
  **id** | **string**| The ID of the account. | 
 **optional** | ***AccountsApiGetAccountOpts** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a pointer to a AccountsApiGetAccountOpts struct
Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------

 **xTraceId** | [**optional.Interface of string**](.md)| Unique identifier associated with this request. | 
 **date** | **optional.String**| A date formatted YYYY-MM-DD. When added to the request, Firefly III will show the account&#x27;s balance on that day.  | 

### Return type

[**AccountSingle**](AccountSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth), [local_bearer_auth](../README.md#local_bearer_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/vnd.api+json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **ListAccount**
> AccountArray ListAccount(ctx, optional)
List all accounts.

This endpoint returns a list of all the accounts owned by the authenticated user. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
 **optional** | ***AccountsApiListAccountOpts** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a pointer to a AccountsApiListAccountOpts struct
Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xTraceId** | [**optional.Interface of string**](.md)| Unique identifier associated with this request. | 
 **limit** | **optional.Int32**| Number of items per page. The default pagination is per 50 items. | 
 **page** | **optional.Int32**| Page number. The default pagination is per 50 items. | 
 **date** | **optional.String**| A date formatted YYYY-MM-DD. When added to the request, Firefly III will show the account&#x27;s balance on that day.  | 
 **type_** | [**optional.Interface of AccountTypeFilter**](.md)| Optional filter on the account type(s) returned | 

### Return type

[**AccountArray**](AccountArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth), [local_bearer_auth](../README.md#local_bearer_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/vnd.api+json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **ListAttachmentByAccount**
> AttachmentArray ListAttachmentByAccount(ctx, id, optional)
Lists all attachments.

Lists all attachments.

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
  **id** | **string**| The ID of the account. | 
 **optional** | ***AccountsApiListAttachmentByAccountOpts** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a pointer to a AccountsApiListAttachmentByAccountOpts struct
Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------

 **xTraceId** | [**optional.Interface of string**](.md)| Unique identifier associated with this request. | 
 **limit** | **optional.Int32**| Number of items per page. The default pagination is per 50 items. | 
 **page** | **optional.Int32**| Page number. The default pagination is per 50 items. | 

### Return type

[**AttachmentArray**](AttachmentArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth), [local_bearer_auth](../README.md#local_bearer_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/vnd.api+json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **ListPiggyBankByAccount**
> PiggyBankArray ListPiggyBankByAccount(ctx, id, optional)
List all piggy banks related to the account.

This endpoint returns a list of all the piggy banks connected to the account. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
  **id** | **string**| The ID of the account. | 
 **optional** | ***AccountsApiListPiggyBankByAccountOpts** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a pointer to a AccountsApiListPiggyBankByAccountOpts struct
Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------

 **xTraceId** | [**optional.Interface of string**](.md)| Unique identifier associated with this request. | 
 **limit** | **optional.Int32**| Number of items per page. The default pagination is per 50 items. | 
 **page** | **optional.Int32**| Page number. The default pagination is per 50 items. | 

### Return type

[**PiggyBankArray**](PiggyBankArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth), [local_bearer_auth](../README.md#local_bearer_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/vnd.api+json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **ListTransactionByAccount**
> TransactionArray ListTransactionByAccount(ctx, id, optional)
List all transactions related to the account.

This endpoint returns a list of all the transactions connected to the account. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
  **id** | **string**| The ID of the account. | 
 **optional** | ***AccountsApiListTransactionByAccountOpts** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a pointer to a AccountsApiListTransactionByAccountOpts struct
Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------

 **xTraceId** | [**optional.Interface of string**](.md)| Unique identifier associated with this request. | 
 **limit** | **optional.Int32**| Number of items per page. The default pagination is per 50 items. | 
 **page** | **optional.Int32**| Page number. The default pagination is per 50 items. | 
 **start** | **optional.String**| A date formatted YYYY-MM-DD.  | 
 **end** | **optional.String**| A date formatted YYYY-MM-DD.  | 
 **type_** | [**optional.Interface of TransactionTypeFilter**](.md)| Optional filter on the transaction type(s) returned. | 

### Return type

[**TransactionArray**](TransactionArray.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth), [local_bearer_auth](../README.md#local_bearer_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/vnd.api+json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **StoreAccount**
> AccountSingle StoreAccount(ctx, body, name, type_, iban, bic, accountNumber, openingBalance, openingBalanceDate, virtualBalance, currencyId, currencyCode, active, order, includeNetWorth, accountRole, creditCardType, monthlyPaymentDate, liabilityType, liabilityDirection, interest, interestPeriod, notes, latitude, longitude, zoomLevel, optional)
Create new account.

Creates a new account. The data required can be submitted as a JSON body or as a list of parameters (in key=value pairs, like a webform).

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
  **body** | [**AccountStore**](AccountStore.md)| JSON array with the necessary account information or key&#x3D;value pairs. See the model for the exact specifications. | 
  **name** | **string**|  | 
  **type_** | [**ShortAccountTypeProperty**](.md)|  | 
  **iban** | **string**|  | 
  **bic** | **string**|  | 
  **accountNumber** | **string**|  | 
  **openingBalance** | **string**|  | 
  **openingBalanceDate** | **time.Time**|  | 
  **virtualBalance** | **string**|  | 
  **currencyId** | **string**|  | 
  **currencyCode** | **string**|  | 
  **active** | **bool**|  | 
  **order** | **int32**|  | 
  **includeNetWorth** | **bool**|  | 
  **accountRole** | [**AccountRoleProperty**](.md)|  | 
  **creditCardType** | [**CreditCardTypeProperty**](.md)|  | 
  **monthlyPaymentDate** | **time.Time**|  | 
  **liabilityType** | [**LiabilityTypeProperty**](.md)|  | 
  **liabilityDirection** | [**LiabilityDirectionProperty**](.md)|  | 
  **interest** | **string**|  | 
  **interestPeriod** | [**InterestPeriodProperty**](.md)|  | 
  **notes** | **string**|  | 
  **latitude** | **float64**|  | 
  **longitude** | **float64**|  | 
  **zoomLevel** | **int32**|  | 
 **optional** | ***AccountsApiStoreAccountOpts** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a pointer to a AccountsApiStoreAccountOpts struct
Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------

























 **xTraceId** | [**optional.Interface of string**](.md)| Unique identifier associated with this request. | 

### Return type

[**AccountSingle**](AccountSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth), [local_bearer_auth](../README.md#local_bearer_auth)

### HTTP request headers

 - **Content-Type**: application/json, application/x-www-form-urlencoded
 - **Accept**: application/json, application/vnd.api+json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **UpdateAccount**
> AccountSingle UpdateAccount(ctx, body, name, iban, bic, accountNumber, openingBalance, openingBalanceDate, virtualBalance, currencyId, currencyCode, active, order, includeNetWorth, accountRole, creditCardType, monthlyPaymentDate, liabilityType, interest, interestPeriod, notes, latitude, longitude, zoomLevel, id, optional)
Update existing account.

Used to update a single account. All fields that are not submitted will be cleared (set to NULL). The model will tell you which fields are mandatory. 

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
  **body** | [**AccountUpdate**](AccountUpdate.md)| JSON array or formdata with updated account information. See the model for the exact specifications. | 
  **name** | **string**|  | 
  **iban** | **string**|  | 
  **bic** | **string**|  | 
  **accountNumber** | **string**|  | 
  **openingBalance** | **string**|  | 
  **openingBalanceDate** | **time.Time**|  | 
  **virtualBalance** | **string**|  | 
  **currencyId** | **string**|  | 
  **currencyCode** | **string**|  | 
  **active** | **bool**|  | 
  **order** | **int32**|  | 
  **includeNetWorth** | **bool**|  | 
  **accountRole** | [**AccountRoleProperty**](.md)|  | 
  **creditCardType** | [**CreditCardTypeProperty**](.md)|  | 
  **monthlyPaymentDate** | **time.Time**|  | 
  **liabilityType** | [**LiabilityTypeProperty**](.md)|  | 
  **interest** | **string**|  | 
  **interestPeriod** | [**InterestPeriodProperty**](.md)|  | 
  **notes** | **string**|  | 
  **latitude** | **float64**|  | 
  **longitude** | **float64**|  | 
  **zoomLevel** | **int32**|  | 
  **id** | **string**| The ID of the account. | 
 **optional** | ***AccountsApiUpdateAccountOpts** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a pointer to a AccountsApiUpdateAccountOpts struct
Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
























 **xTraceId** | [**optional.Interface of string**](.md)| Unique identifier associated with this request. | 

### Return type

[**AccountSingle**](AccountSingle.md)

### Authorization

[firefly_iii_auth](../README.md#firefly_iii_auth), [local_bearer_auth](../README.md#local_bearer_auth)

### HTTP request headers

 - **Content-Type**: application/json, application/x-www-form-urlencoded
 - **Accept**: application/json, application/vnd.api+json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

